Camera

Struct Camera 

pub struct Camera<S, P, D, Sm, K>
where S: RealField + Copy, P: ProjectionModel<S>, D: DistortionModel<S>, Sm: SensorModel<S>, K: IntrinsicsModel<S>,
{ pub proj: P, pub dist: D, pub sensor: Sm, pub k: K, /* private fields */ }
A composable camera model: projection -> distortion -> sensor -> intrinsics.

Fields

proj: P

Projection model (e.g. pinhole).

dist: D

Distortion model (e.g. Brown-Conrady).

sensor: Sm

Sensor model (e.g. identity or tilted homography).

k: K

Intrinsics model (K).

Implementations

Source

impl<S, P, D, Sm, K> Camera<S, P, D, Sm, K>
where S: RealField + Copy, P: ProjectionModel<S>, D: DistortionModel<S>, Sm: SensorModel<S>, K: IntrinsicsModel<S>,

pub fn new(proj: P, dist: D, sensor: Sm, k: K) -> Camera<S, P, D, Sm, K>

Build a camera from its component models.

pub fn project_point_c( &self, p_c: &Matrix<S, Const<3>, Const<1>, ArrayStorage<S, 3, 1>>, ) -> Option<OPoint<S, Const<2>>>

Project a 3D point in camera coordinates into pixel coordinates.

Returns None if the point is behind the camera or not projectable.

pub fn project_point( &self, p_c: &OPoint<S, Const<3>>, ) -> Option<OPoint<S, Const<2>>>

Project a 3D point in camera coordinates into pixel coordinates.

This is a convenience wrapper around project_point_c.

pub fn backproject_pixel(&self, px: &OPoint<S, Const<2>>) -> Ray<S>

Backproject a pixel to a point on the z = 1 plane in camera coordinates.